Module graph

Module graph 

A generic Graph, containing vertices of type V, connected by type E

Structs

Graph
A generic Graph, containing vertices of type V, connected by type E
Handle
Handle to Vertices in the graph